#!/bin/bash
# AWXforecast v1.1 - 17/3/24
#
# Get your local Forecast from BoM for FreePBX (Sorry, Australian only).
# Set your areas IDQ Number below, you can find your IDQ No. at the bottom
# of most areas forecast pages on the BoM's web site.
#
# Forecast's cleaned up, sent through TTS, saved as wav, cleaned wav and
# create *law files, then puts AWXforecast.* in freepbx's sound directory.
#
# No suitable TTS service found that takes automated script submissions and
# returns a file, so for moment we stick with espeak, until we find better
# with non robotic sounding voices :)   cepstral is a paid alternative.
#
# Don't piss off the BoM, use from cron after their scheduled forecast and
# the odd extra release times ONLY!  This is a suitable cron entry -
#
#  30 1,5,11,17,21 * * * /usr/local/bin/AWXforecast.sh > /dev/null 2>&1
#
# For security and integrity purposes we set the full path to each binary.
# For Asterisk and FreePBX configuration see blog post:
# https://blog.ausics.net/archives/159-Add-Current-Weather-In-FreePBX.html
#
# Copyright © Noel Butler <noelb@ausics.net> 2024  All Rights Reserved.
############################################################################
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License v3 as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
# more details. The original copyright notice must always remain unaltered.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
############################################################################

# Set your local IDQ
IDQNUM='IDQ10090.txt'     # IDQ10090 SEQ Area Forecast

############################################################################


cd /var/tmp


if [ -f /var/tmp/$IDQNUM ]; then
	/bin/rm /var/tmp/$IDQNUM
fi


/usr/bin/wget ftp://ftp.bom.gov.au/anon/gen/fwo/$IDQNUM

/usr/bin/test -s /var/tmp/$IDQNUM || exit 0


/usr/bin/perl -i -ne 'print if /Forecast for the rest/ .. /The next routine forecast/' $IDQNUM


# You might want to comment these out if your not on the sunny coast :)
/usr/bin/perl -i -ne 'print unless /Surfers Paradise/' $IDQNUM
/usr/bin/perl -i -ne 'print unless /Gatton/' $IDQNUM
/usr/bin/perl -i -ne 'print unless /Beaudesert/' $IDQNUM
/usr/bin/perl -i -ne 'print unless /Ipswich/' $IDQNUM
/usr/bin/perl -i -ne 'print unless /Logan Central/' $IDQNUM
# end edit



/usr/bin/perl -i -pe "s/UV Index predicted to reach/UV Index predicted to reach\./g;" $IDQNUM
/usr/bin/perl -i -pe "s/\[/ \. /g;" $IDQNUM
/usr/bin/perl -i -pe "s/\]/ \. /g;" $IDQNUM
/usr/bin/perl -i -pe "s/km\/h/kilometers per hour/g;" $IDQNUM
/usr/bin/perl -i -pe 's/(Max)(.*)$/$1$2./g' $IDQNUM



/usr/bin/espeak -f /var/tmp/$IDQNUM -ven-us+f2 -s160 -w /var/tmp/SEQ.wav
/usr/bin/test -s /var/tmp/SEQ.wav || exit 0


# espeak produces 22k wav files, not compatible with asterisk, so fix it here
/usr/bin/sox /var/tmp/SEQ.wav -r 8000 -c 1 -t al /var/tmp/AWXforecast.alaw
/usr/bin/sox /var/tmp/SEQ.wav -r 8000 -c 1 -t ul /var/tmp/AWXforecast.ulaw
/usr/bin/sox /var/tmp/SEQ.wav -r 8000 -c 1 /var/tmp/AWXforecast.wav


/bin/mv /var/tmp/AWXforecast.wav /var/lib/asterisk/sounds
/bin/mv /var/tmp/AWXforecast.*law /var/lib/asterisk/sounds

/bin/rm /var/tmp/SEQ.wav





/bin/echo ""
/bin/echo "Updated BoM Forecast for FreePBX"
/bin/echo ""

exit 0

